@@ -73,7 +73,7 @@ class GapFiller(val region: GenomeRegion) {
       else if (Pilon.debug) println("Gap closed but bad size: " + break + " " + closedLength)
     }
     if (solutionOK) solution
-    else if (isGap || ((Pilon.fixList contains 'breaks) && loop.length == 0)) {
+    else if (isGap || (Pilon.fixBreaks && loop.length == 0)) {
       // build partial solution using consensus from each side, opening gap if necessary
       val fromRight = consensusFromRight(pathsFromRight)
       val fromLeft = consensusFromLeft(pathsFromLeft)
@@ -127,12 +127,10 @@ class GapFiller(val region: GenomeRegion) {
     assembler.addReads(reads)
     if (Pilon.dumpReads) writeBam(break.toString, reads)
     assembler.buildGraph
-    if (Pilon.fixList.contains('novel) && Pilon.novelContigs != Nil) {
+    if (Pilon.fixNovel && Pilon.novelContigs != Nil) {
       assembler.addGraphSeqs(Pilon.novelContigs)
-    } 
+    }
     if (Pilon.debug) println("assembleIntoBreak: " + break + " " + assembler)
-      
-    //if (Pilon.fixList contains 'novelbreaks) assembler.novel
 
     val startOffset = breakRadius
     var start = (break.start - startOffset) max region.start
@@ -169,22 +167,22 @@ class GapFiller(val region: GenomeRegion) {
         solutionSet += s
       }
     }
-    val solutions = solutionSet.toList sortWith { (a,b) => a._3.length - a._2.length > b._3.length - b._2.length }
-    var solutionLengths = Set[Int]()
-    solutions map {s => solutionLengths += s._3.length - s._2.length}
+
+    val solutions = solutionSet.toList sortWith { (a,b) => a._3.length + a._2.length < b._3.length + b._2.length }
+    var solutionLengths = solutionSet map {s => s._3.length - s._2.length}
 
     if (Pilon.debug) {
       println("breakJoins: " + solutions.length + " solutions; lengths " + solutionLengths)
       for (s <- solutions) println("  " + s)
     }
     if (solutionLengths.size == 1) {
-      if (Pilon.debug) println("...all solutions of same length, using first above")
+      if (Pilon.debug) println("...all solutions of same length, using smallest total change above")
       List(solutions.head)
     } else{
       solutions
     }
   }
-  
+
   def joinBreak(startArg: Int, forward: String, reverse: String, stopArg: Int) = {
     var start = startArg
     var stop = stopArg
@@ -203,13 +201,13 @@ class GapFiller(val region: GenomeRegion) {
     if (patch != "") {
     	val solution = trimPatch(start, patch, stop)
     	start = solution._1
-    	
+
     	if (solution._2 == solution._3) {
     	  if (Pilon.debug) println("...no change")
     	  solution
     	} else {
     	  if (Pilon.debug)
-    	    println("...start=" + start + " ref=(" + solution._2.length + ")" + solution._2 
+    	    println("...start=" + start + " ref=(" + solution._2.length + ")" + solution._2
     	    		+ " new=(" + solution._3.length + ")" + solution._3)
     	  solution
     	}
@@ -218,7 +216,7 @@ class GapFiller(val region: GenomeRegion) {
     	noSolution
     }
   }
-  
+
   def properOverlap(left: String, right: String, minOverlap: Int): String = {
 
     def substrMatch(a: String, aOffset: Int, b: String, bOffset: Int, len: Int): Boolean = {
@@ -304,7 +302,7 @@ class GapFiller(val region: GenomeRegion) {
     if (estimatedLength == 0) {
       reads = recruitReads(region)
     } else {
-      val unpairedBams = region.bamsOfType('unpaired)
+      val unpairedBams = region.bamsOfType("unpaired")
       for (bam <- unpairedBams) {
         reads ++= bam.readsInRegion(leftFlank)
         reads ++= bam.readsInRegion(rightFlank)
@@ -324,14 +322,14 @@ class GapFiller(val region: GenomeRegion) {
     assembler.addReads(reads)
     assembler.buildGraph
     val (forward, reverse, loop) = assembler.multiBridge(left, right)
-    if (Pilon.verbose && !loop.isEmpty)
+    if (Pilon.verbose && loop.nonEmpty)
       println(" loop: " + loop.length + " " + loop)
 
     var patches = Set[String]()
     for (f <- forward; r <- reverse) {
       val patch = properOverlap(f, r, GapFiller.k)
       // We should be very close in our closure estimation from alignments. Don't allow
-      if (!patch.isEmpty && (estimatedLength == 0 || (patch.length - 2 * breakRadius).abs < estimatedLengthSlop)) {
+      if (patch.nonEmpty && (estimatedLength == 0 || (patch.length - 2 * breakRadius).abs < estimatedLengthSlop)) {
         patches += patch
       }
     }
@@ -340,7 +338,7 @@ class GapFiller(val region: GenomeRegion) {
     }
     val lengths = patches.map(_.length).toSet
     if (Pilon.verbose)
-      println(patches.size + " patches; lengths " + lengths)
+      println(s"{$patches.size} patches; lengths $lengths")
 
     if (lengths.size == 1 && (estimatedLength == 0 || loop.isEmpty || (loop.length - estimatedLength).abs < estimatedLengthSlop)) {
       val patch = patches.head
@@ -358,11 +356,11 @@ class GapFiller(val region: GenomeRegion) {
 
   def breakRadius = {
     val minRadius = 3 * Assembler.K
-    val inserts = region.bamsOfType('frags) map {bam => bam.insertSizeMean /*+ bam.insertSizeSigma*/}
+    val inserts = region.bamsOfType("frags") map {bam => bam.insertSizeMean /*+ bam.insertSizeSigma*/}
     val insertMean = if (inserts.length > 0) (inserts.sum / inserts.length).round.toInt else 0
     minRadius max insertMean
   }
-    
+
   def recruitReadsFromBams(reg: Region, bams: List[BamFile]) = {
     var reads = List[SAMRecord]()
     for (b <- bams) {
@@ -373,37 +371,37 @@ class GapFiller(val region: GenomeRegion) {
     reads
   }
 
-  def recruitReadsOfType(reg: Region, bamType: Symbol) = {
+  def recruitReadsOfType(reg: Region, bamType: String) = {
     recruitReadsFromBams(reg, region.bamsOfType(bamType))
   }
 
   //def recruitFrags(reg: Region) = mateMapOfType(reg, 'frags).values.toList
-  def recruitFrags(reg: Region) = recruitReadsOfType(reg, 'frags)
+  def recruitFrags(reg: Region) = recruitReadsOfType(reg, "frags")
 
   def recruitJumps(reg: Region) = {
     var reads = List[SAMRecord]()
-    for (b <- region.bamsOfType('jumps)) {
+    for (b <- region.bamsOfType("jumps")) {
       reads ++= b.recruitBadMates(reg)
     }
-    if (Pilon.debug) 
+    if (Pilon.debug)
       println("# Recruiting jump bad mates: count=" + reads.length)
     reads
   }
 
   def recruitUnpaired(reg: Region) =
-    if (!Pilon.longread) recruitReadsOfType(reg, 'unpaired) else Nil
+    if (!Pilon.longread) recruitReadsOfType(reg, "unpaired") else Nil
 
   def recruitLocalReads(reg: Region) = recruitFrags(reg) ++ recruitUnpaired(reg)
 
   def recruitLongReads(reg: Region) = {
-    recruitReadsFromBams(reg, region.bamsOfType('unpaired).filter(_.longReadType > 0))
+    recruitReadsFromBams(reg, region.bamsOfType("unpaired").filter(_.longReadType > 0))
   }
 
   def recruitReads(reg: Region) = {
     recruitLocalReads(reg) ++ recruitJumps(reg) // ++ recruitLongReads(reg)
   }
 
-  def writeBam(fileName: String, reads: List[SAMRecord]) {
+  def writeBam(fileName: String, reads: List[SAMRecord]) = {
     val file = new File(fileName + ".sam")
     val header = new SAMFileHeader()
     header.addSequence(new SAMSequenceRecord(region.contig.getName, region.contig.getBases.length))
