@@ -86,43 +86,36 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
 
     bamFiles foreach {_.validateSeqs(contigsOfInterest)}
 
-    if (Pilon.strays || Pilon.fixList.contains('circles)) {
+    if (Pilon.strays || Pilon.fixCircles) {
       println("Scanning BAMs")
-      // Scan BAMs in parallel
-      //bamFiles.filter({_.bamType != 'unpaired}).par.map(_.scan(contigsOfInterest))
-      bamFiles.par.map(_.scan(contigsOfInterest))
+      bamFiles.map(_.scan(contigsOfInterest))
     }
 
     val circles = Scaffold.findHgapCircles(bamFiles)
 
     // If assemble novel sequence up front, so that we can potentially place the
     // contigs into scaffolds when we process them.
-    if (Pilon.fixList contains 'novel)
+    if (Pilon.fixNovel)
       Pilon.novelContigs = assembleNovel(bamFiles)    
 
     var chunks = regions.map(_._2).flatten
-    if (Pilon.threads > 1) {
-      // Do parallel processing randomly to even out load if all the 
-      // big chunks are early in the file
-      chunks = Random.shuffle(chunks)
-    }
-    chunks.par foreach { r =>
+    chunks foreach { r =>
       println("Processing " + r)
       r.initializePileUps
       bamFiles foreach { r.processBam(_) }
       r.postProcess
-      if ((Pilon.fixList contains 'circles) &&
+      if ((Pilon.fixCircles) &&
         /*(r.contig.length < 5000 && r.contig.length >= 1000) ||*/ (circles contains r.contig.getName)) {
-        if (Pilon.verbose) println(r + " might be a circle!")
+        if (Pilon.verbose) println(s"$r might be a circle!")
         r.closeCircle(circles.getOrElse(r.contig.getName, 0))
       }
-      if (Pilon.vcf || !Pilon.fixList.intersect(Set('snps, 'indels, 'gaps, 'local)).isEmpty) {
+      if (Pilon.vcf || Pilon.fixSnps || Pilon.fixIndels || Pilon.fixGaps || Pilon.fixLocal) {
         r.identifyAndFixIssues
         // If we don't need pileups for VCF later, free up the memory now!
         if (!Pilon.vcf) r.finalizePileUps
       }
-      println(r + " log:")
-      r.printLog
+      println(s"$r log:")
+      r.printLog()
       println("Finished processing " + r)
     }
 
@@ -131,7 +124,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
                           new PrintWriter(new BufferedWriter(new FileWriter(changesFile)))
                         else null
     val fastaFile = Pilon.outputFile(".fasta")
-    val fastaWriter = if (!Pilon.fixList.isEmpty)
+    val fastaWriter = if (Pilon.fixSnps || Pilon.fixIndels || Pilon.fixGaps || Pilon.fixLocal || Pilon.fixNovel)
 	                      new PrintWriter(new BufferedWriter(new FileWriter(fastaFile)))
                       else null
 
@@ -160,7 +153,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
         }
       }
       // Write the FASTA all at once rather than in chunks for formatting reasons
-      if (!Pilon.fixList.isEmpty) {
+      if (fastaWriter != null) {
         println("Writing updated " + newName + " to " + fastaFile)
         val fixedRegions = reg._2 map { _.bases }
         val bases = fixedRegions reduceLeft {_ ++ _} map {_.toChar} mkString ""
@@ -168,7 +161,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
       }
     }
 
-    if (Pilon.fixList contains 'novel) {
+    if (Pilon.fixNovel) {
       val novelContigs = Pilon.novelContigs
       for (n <- 0 until novelContigs.length) {
         val header = "pilon_novel_%03d".format(n + 1)
@@ -176,7 +169,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
         writeFastaElement(fastaWriter, header, novelContigs(n))
       }
     }
-    if (!Pilon.fixList.isEmpty) fastaWriter.close
+    if (fastaWriter != null) fastaWriter.close
     if (Pilon.vcf) vcf.close
     if (Pilon.changes) changesWriter.close
     coverageSummary(bamFiles)
@@ -187,7 +180,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
     var totalBaseCount: Long = 0
     for ((t,files) <- bamTypes) {
       val typeBaseCount = files.map(_.baseCount).sum
-      println("Mean " + t.name + " coverage: " + roundDiv(typeBaseCount, genomeSize))
+      println("Mean " + t + " coverage: " + roundDiv(typeBaseCount, genomeSize))
       totalBaseCount += typeBaseCount
     }
     println("Mean total coverage: " + roundDiv(totalBaseCount, genomeSize))
@@ -204,16 +197,16 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
       if (Pilon.verbose) print("..." + contig.getName)
     }
     //genomeGraph.buildGraph
-    if (Pilon.verbose) println
+    if (Pilon.verbose) println()
     val assembler = new Assembler()
-    bamFiles filter {_.bamType != 'jumps} foreach { bam =>
+    bamFiles filter {_.bamType != "jumps"} foreach { bam =>
       val reads = bam.getUnaligned
       print("..." + reads.length + " unmapped reads")
       assembler.addReads(reads)
     }
     print("...assembling contigs")
     val contigs = assembler.novel(genomeGraph)
-    println
+    println()
     val contigLengths = contigs map {_.length}
     println("Assembled %d novel contigs containing %d bases".format(contigs.length, contigLengths.sum))
     contigs
@@ -244,7 +237,7 @@ class GenomeFile(val referenceFile: File, val targets : String = "") {
 
   def parseTargetFile(fileName: String) = {
     try {
-      Source.fromFile(fileName).getLines.flatMap({parseTargetString(_)}).toList
+      Source.fromFile(fileName).getLines().flatMap({parseTargetString(_)}).toList
     } catch {
       case ioe: Exception => Nil
     }
