@@ -22,9 +22,18 @@ package org.broadinstitute.pilon
 import java.io.File
 
 object Pilon {
-  // types of fixing we know about
-  val fixChoices = Set('snps, 'indels, 'gaps, 'local)
-  val experimentalFixChoices = Set('amb, 'breaks, 'circles, 'novel, 'scaffolds)
+  val fixChoices= Set("snps", "indels", "gaps", "local")
+  val experimentalFixChoices = Set("amb", "breaks", "circles", "novel", "scaffolds")
+
+  var fixSnps = false
+  var fixIndels = false
+  var fixGaps = false
+  var fixLocal = false
+  var fixAmb = false
+  var fixBreaks = false
+  var fixCircles = false
+  var fixNovel = false
+  var fixScaffolds = false
 
   // input parameters
   var bamFiles = List[BamFile]()
@@ -61,7 +70,6 @@ object Pilon {
   var pacbio = false
   var nanopore = false
   var strays = true
-  var threads = 1
   var trSafe = true
 
   // Global computed data
@@ -70,7 +78,7 @@ object Pilon {
   // for logging to output files
   var commandArgs = Array[String]()
 
-  def main(args: Array[String]) {
+  def main(args: Array[String]) = {
     commandArgs = args
     println(Version.version)
     optionParse(args.toList)
@@ -84,11 +92,9 @@ object Pilon {
       }
     }
 
-    setDefaultParallelism(threads)
-
     // Stray computation is expensive up front, so only turn it on
     // if we're doing local reassembly
-    strays &= (fixList contains 'gaps) || (fixList contains 'local) || (fixList contains 'scaffolds)
+    strays &= fixGaps || fixLocal || fixScaffolds
 
     if (bamFiles.length == 0) {
       println(usage)
@@ -101,7 +107,7 @@ object Pilon {
     println("Genome: " + genomePath)
     val genome = new GenomeFile(new File(genomePath), targets)
 
-    println("Fixing " + (fixList map {_.name} mkString(", ")))
+    println("Fixing " + (fixList mkString(", ")))
     genome.processRegions(bamFiles)
 
     if (tracks) {
@@ -111,9 +117,8 @@ object Pilon {
 
   }
 
-  def optionParse(list: List[String]) : Unit = {
+  def optionParse(list: List[String]) : Unit  = {
     list match {
-      case Nil => Nil
       case "--help" :: tail =>
         println(usage)
         print(help)
@@ -123,7 +128,7 @@ object Pilon {
         // println(Version.version)
         sys.exit(0)
       case "--bam" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'bam)
+        bamFiles ::= new BamFile(new File(value), "bam")
         optionParse(tail)
       case "--changes" :: tail =>
         changes = true
@@ -157,7 +162,7 @@ object Pilon {
         flank = value.toInt
         optionParse(tail)
       case "--frags" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'frags)
+        bamFiles ::= new BamFile(new File(value), "frags")
         optionParse(tail)
       case "--gapmargin" :: value :: tail =>
         gapMargin = value.toInt
@@ -166,7 +171,7 @@ object Pilon {
         genomePath = value
         optionParse(tail)
       case "--jumps" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'jumps)
+        bamFiles ::= new BamFile(new File(value), "jumps")
         optionParse(tail)
       case "--K" :: value :: tail =>
         Assembler.K = value.toInt
@@ -187,7 +192,7 @@ object Pilon {
         multiClosure = true
         optionParse(tail)
       case "--nanopore" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'unpaired, 'nanopore)
+        bamFiles ::= new BamFile(new File(value), "unpaired", "nanopore")
         longread = true
         nanopore = true
         optionParse(tail)
@@ -204,7 +209,7 @@ object Pilon {
         outdir = value
         optionParse(tail)
       case "--pacbio" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'unpaired, 'pacbio)
+        bamFiles ::= new BamFile(new File(value), "unpaired", "pacbio")
         longread = true
         pacbio = true
         optionParse(tail)
@@ -212,7 +217,8 @@ object Pilon {
         targets = value
         optionParse(tail)
       case "--threads" :: value :: tail =>
-        threads = value.toInt
+        println("--threads argument no longer supported; ignoring!")
+        //threads = value.toInt
         optionParse(tail)
       case "--tracks" :: tail =>
         tracks = true
@@ -221,12 +227,12 @@ object Pilon {
       //  trSafe = true
       //  optionParse(tail)
       case "--unpaired" :: value :: tail =>
-        bamFiles ::= new BamFile(new File(value), 'unpaired)
+        bamFiles ::= new BamFile(new File(value), "unpaired")
         optionParse(tail)
       case "--variant" :: tail =>
         // variant calling mode
         vcf = true
-        fixList += 'breaks
+        fixList += "breaks"
         optionParse(tail)
         //multiClosure = true
       case "--vcf" :: tail =>
@@ -244,10 +250,21 @@ object Pilon {
       case option :: tail =>
         println("Unknown option " + option)
         sys.exit(1)
+      case Nil =>
     }
+    fixSnps = fixList contains "snps"
+    fixIndels = fixList contains "indels"
+    fixGaps = fixList contains "gaps"
+    fixLocal = fixList contains "local"
+    fixAmb = fixList contains "amb"
+    fixBreaks = fixList contains "breaks"
+    fixCircles = fixList contains "circles"
+    fixNovel = fixList contains "novel"
+    fixScaffolds = fixList contains "scaffolds"
   }
   
   def parseFixList(fix: String) = {
+    // types of fixing we know about
     val fixes = fix.split(",")
     if (fix(0) != '+' && fix(0) != '-') fixList = Set.empty
     for (f <- fixes) {
@@ -255,7 +272,7 @@ object Pilon {
       else if (f == "none") fixList = Set.empty
       else {
         val plusMinus = if (f(0) == '-') f(0) else '+'
-        val fsym = if (f(0) == plusMinus) Symbol(f.substring(1)) else Symbol(f)
+        val fsym = if (f(0) == plusMinus) f.substring(1) else f
         if (fixChoices contains fsym) {
           if (plusMinus == '+') fixList += fsym
           else fixList -= fsym
@@ -264,14 +281,14 @@ object Pilon {
           println("Warning: experimental fix option " + f)
           if (plusMinus == '+') fixList += fsym
           else fixList -= fsym
-        } else if (fsym == 'bases) {
+        } else if (fsym == "bases") {
           // for backward compatibility, 'bases applies to both 'snps and 'indels
           if (plusMinus == '+') {
-            fixList += 'snps
-            fixList += 'indels
+            fixList += "snps"
+            fixList += "indels"
           } else {
-            fixList -= 'snps
-            fixList -= 'indels
+            fixList -= "snps"
+            fixList -= "indels"
           }
         } else {
           println("Error: unknown fix option " + f)
@@ -286,21 +303,8 @@ object Pilon {
     val filePath = if (Pilon.outdir == "") fileName else Pilon.outdir + "/" + fileName
     new File(filePath)
   }
-  
-  // Ugly, but thank you http://stackoverflow.com/questions/17865823
-  def setDefaultParallelism(numThreads: Int): Unit = {
-    val parPkgObj = scala.collection.parallel.`package`
-    val defaultTaskSupportField = parPkgObj.getClass.getDeclaredFields.find{
-      _.getName == "defaultTaskSupport"
-    }.get
 
-    defaultTaskSupportField.setAccessible(true)
-    defaultTaskSupportField.set(
-      parPkgObj,
-      new scala.collection.parallel.ForkJoinTaskSupport(
-        new scala.concurrent.forkjoin.ForkJoinPool(numThreads)))
-  }
-  
+
   val usage = """
     Usage: pilon --genome genome.fasta [--frags frags.bam] [--jumps jumps.bam] [--unpaired unpaired.bam]
                  [...other options...]
@@ -324,6 +328,10 @@ object Pilon {
            --bam any.bam
               A bam file of unknown type; Pilon will scan it and attempt to classify it as one
               of the above bam types.
+           --nanopore ont.bam
+              A bam file containing Oxford Nanopore read alignments. Experimental.
+           --pacbio pb.bam
+              A bam file containing Pacific Biosciences read alignments. Experimental.
          OUTPUTS:
            --output prefix
               Prefix for output files
@@ -377,8 +385,6 @@ object Pilon {
               scaffold00001 and coordinates 10000-20000 of scaffold00002.
               If "targetlist" is the name of a file, each line will be treated as a target
               specification.
-           --threads
-              Degree of parallelism to use for certain processing (default 1). Experimental.
            --verbose
               More verbose output.
            --debug
